@@ -2,7 +2,7 @@ use std::path::PathBuf;
 use structopt::StructOpt;
 
 #[derive(Debug, StructOpt)]
-#[structopt(name = "Mil", about = "Mil compiler")]
+#[structopt(name = "mil", about = "Mil compiler")]
 pub struct BuildCmd {
     /// Display VM state at each step of execution.
     #[structopt(short, long)]
