@@ -194,6 +194,18 @@ impl Env {
         mangler: &mut LinearMangler,
     ) -> Result<UnrolledExpr, ParseErr> {
         match expr {
+            /*
+            Expr::Checked(expr, default) => {
+                let var = mangler.next();
+                Ok(UnrolledExpr::Let(
+                        vec![(var, self.expand_mangle_fns(expr, mangler)?)],
+                        vec![],
+                        Box::new(UnrolledExpr::If(
+                            Box::new(UnrolledExpr::BuiltIn(Box::new(ExpandedBuiltIn::Oflo))),
+                            Box::new(self.expand_mangle_fns(default, mangler)?),
+                            Box::new(UnrolledExpr::Var(var))))))
+            }
+            */
             // A variable should already be mangled, find its mangled value
             Expr::Var(x) => {
                 let v = try_get_var(x, &self.mangled)?;
@@ -230,6 +242,11 @@ impl Env {
             }
             // For a builtin op, expand its arguments and cast into an ExpandedBuiltIn
             Expr::BuiltIn(b) => match &**b {
+                /*
+                BuiltIn::Oflo => Ok(UnrolledExpr::BuiltIn(Box::new(
+                    ExpandedBuiltIn::<UnrolledExpr>::Oflo,
+                ))),
+                */
                 BuiltIn::Vempty => Ok(UnrolledExpr::BuiltIn(Box::new(
                     ExpandedBuiltIn::<UnrolledExpr>::Vempty,
                 ))),
@@ -269,6 +286,11 @@ impl Env {
                 BuiltIn::Mul(e1, e2) => {
                     self.expand_binop(e1, e2, ExpandedBuiltIn::<UnrolledExpr>::Mul, mangler)
                 }
+                BuiltIn::Exp(e1, e2, k) => Ok(UnrolledExpr::BuiltIn(Box::new(ExpandedBuiltIn::<UnrolledExpr>::Exp(
+                    self.expand_mangle_fns(&e1, mangler)?,
+                    self.expand_mangle_fns(&e2, mangler)?,
+                    *k,
+                )))),
                 BuiltIn::Div(e1, e2) => {
                     self.expand_binop(e1, e2, ExpandedBuiltIn::<UnrolledExpr>::Div, mangler)
                 }
