@@ -15,6 +15,7 @@ pub enum ExpandedBuiltIn<E> {
     Add(E, E),
     Sub(E, E),
     Mul(E, E),
+    Exp(E, E, u8),
     Div(E, E),
     Rem(E, E),
     // Logical
@@ -56,6 +57,8 @@ pub enum ExpandedBuiltIn<E> {
     TypeQ(E),
     // Stack ops
     Dup(E),
+    // Overflow
+    //Oflo,
     // Heap access
     Load(HeapPos),
     Store(HeapPos),
@@ -69,6 +72,7 @@ impl<E> ExpandedBuiltIn<E> {
             ExpandedBuiltIn::Add(x, y) => toret.extend_from_slice(&[x, y]),
             ExpandedBuiltIn::Sub(x, y) => toret.extend_from_slice(&[x, y]),
             ExpandedBuiltIn::Mul(x, y) => toret.extend_from_slice(&[x, y]),
+            ExpandedBuiltIn::Exp(x, y, _) => toret.extend_from_slice(&[x, y]),
             ExpandedBuiltIn::Div(x, y) => toret.extend_from_slice(&[x, y]),
             ExpandedBuiltIn::Rem(x, y) => toret.extend_from_slice(&[x, y]),
             ExpandedBuiltIn::Not(x) => toret.push(x),
@@ -109,6 +113,7 @@ impl<E> ExpandedBuiltIn<E> {
             ExpandedBuiltIn::Add(x, y) => ExpandedBuiltIn::Add(f(x), f(y)),
             ExpandedBuiltIn::Sub(x, y) => ExpandedBuiltIn::Sub(f(x), f(y)),
             ExpandedBuiltIn::Mul(x, y) => ExpandedBuiltIn::Mul(f(x), f(y)),
+            ExpandedBuiltIn::Exp(x, y, k) => ExpandedBuiltIn::Exp(f(x), f(y), k),
             ExpandedBuiltIn::Div(x, y) => ExpandedBuiltIn::Div(f(x), f(y)),
             ExpandedBuiltIn::Rem(x, y) => ExpandedBuiltIn::Rem(f(x), f(y)),
             ExpandedBuiltIn::Not(x) => ExpandedBuiltIn::Not(f(x)),
@@ -157,6 +162,8 @@ pub enum BuiltIn {
     Div(Expr, Expr),
     /// (% 10 3)
     Rem(Expr, Expr),
+    /// (** 10 3)
+    Exp(Expr, Expr, u8),
 
     // Logical
     // ---------
@@ -387,24 +394,20 @@ pub enum Expr {
     BuiltIn(Box<BuiltIn>),
     /// Application of a user-defined function to some arguments.
     App(Symbol, Vec<Expr>),
-    // Assign a value stored on the heap to a symbol
-    //Set(Symbol, Box<Expr>),
     /// A variable is a pointer to a location on the heap.
     Var(Symbol),
     /// Reserved identities for values available in every MelVM script.
     Reserved(Reserved),
     /// Bind a symbol to a value within the scope of a given expression.
     Let(Vec<(Symbol, Expr)>, Vec<Statement>, Box<Expr>),
-    // Set a symbol to point to a location.
-    //SetTo(Symbol, Box<Expr>),
     /// If expression.
     If(Box<Expr>, Box<Expr>, Box<Expr>),
-    // Loop an expression a specified number of  times.
-    //Loop(u16, Box<Expr>),
     /// Hash the return value of an expression.
     Hash(u16, Box<Expr>),
     /// Sign a message with a public key and check that it matches a signature.
     Sigeok(u16, Box<Expr>, Box<Expr>, Box<Expr>),
+    // Run the expression and then check overflow, with a default value if true.
+    //Checked(Box<Expr>, Box<Expr>),
 }
 
 /// An expression where all applications are on [BuiltIn] operators.
